package statAnalysis;

import java.util.List;
import java.util.Map;

import powerEvaluators.PowerEvaluator;
import powerEvaluators.PowerExpectedDamageEvaluator;
import statAnalysis.singleStatAnalysis.SingleStatAnalysis;

/**
 * A head-to-head matchup {@link StatAnalysisProcessor} which compares expected damage.
 */
public class OneOnOneExpectedDamageStatAnalysisProcessor extends OneOnOneStatAnalysisProcessor
{
  /**
   * Constructor.
   */
  public OneOnOneExpectedDamageStatAnalysisProcessor()
  {
  }
  
  /**
   * Constructor.
   * 
   * @param label
   *          A string describing this analyser.
   */
  public OneOnOneExpectedDamageStatAnalysisProcessor(List<SingleStatAnalysis<? extends StatAnalysisProcessor>> statAnalysisList,
      Class<PowerExpectedDamageEvaluator> powerEvaluator1Class, Class<PowerExpectedDamageEvaluator> powerEvaluator2Class)
  {
    super(statAnalysisList, powerEvaluator1Class, powerEvaluator2Class);
  }

  /**
   * If the expected damage of the first {@link PowerEvaluator} in the
   * one-on-one competition is greater than or equal to the expected damage of
   * the second {@link PowerEvaluator}, this method returns true.
   */
  @Override
  public boolean isAWin(Map<Class, ? extends PowerExpectedDamageEvaluator> statsMap)
  {
    return (statsMap.get(getContestant1Class()).getExpectedDamage() >= statsMap.get(getContestant2Class())
        .getExpectedDamage());
  }
}
