package statAnalysis;

import java.util.List;
import java.util.Map;

import powerEvaluators.PowerEvaluator;
import powerEvaluators.PowerExpectedDamageEvaluator;
import statAnalysis.singleStatAnalysis.SingleStatAnalysis;

/**
 * {@link StatAnalysisProcessor} which tracks 'wins' between two
 * {@link PowerEvaluator}s in a head-to-head matchup.
 */
public abstract class OneOnOneStatAnalysisProcessor extends StatAnalysisProcessor
{
  /**
   * The number of successes/wins recorded by this analyser.
   */
  private int winCounter;
  /**
   * Contestant #1.
   */
  private Class<PowerEvaluator> contestant1Class;
  /**
   * Contestant #2.
   */
  private Class<PowerEvaluator> contestant2Class;

  /**
   * 
   * @return True if the current
   */
  public abstract boolean isAWin(Map<Class, ? extends PowerExpectedDamageEvaluator> statsMap);

  /**
   * Constructor.
   */
  public OneOnOneStatAnalysisProcessor()
  {
  }

  /**
   * Constructor.
   * 
   * @param label
   *          A string describing this analyser.
   */
  public OneOnOneStatAnalysisProcessor(List<SingleStatAnalysis<? extends StatAnalysisProcessor>> statAnalysisList,
      Class powerEvaluator1Class, Class powerEvaluator2Class)
  {
    super(statAnalysisList);
    this.contestant1Class = powerEvaluator1Class;
    this.contestant2Class = powerEvaluator2Class;
  }

  @Override
  public void analyseStats(Map<Class, ? extends PowerExpectedDamageEvaluator> statsMap)
  {
    if (isAWin(statsMap))
    {
      winCounter++;
    }
    super.analyseStats(statsMap);
  }

  /**
   * 
   * @return The number of wins tracked by this analyser.
   */
  public int getWinCounter()
  {
    return winCounter;
  }

  /**
   * 
   * @return {@link #contestant1Class}
   */
  public Class getContestant1Class()
  {
    return contestant1Class;
  }

  /**
   * 
   * @param contestant1Class
   *          {@link #contestant1Class}
   */
  public void setContestant1Class(Class contestant1Class)
  {
    this.contestant1Class = contestant1Class;
  }

  /**
   * 
   * @return {@link #contestant2Class}
   */
  public Class getContestant2Class()
  {
    return contestant2Class;
  }

  /**
   * 
   * @param contestant2Class
   *          {@link #contestant2Class}
   */
  public void setContestant2Class(Class contestant2Class)
  {
    this.contestant2Class = contestant2Class;
  }
}
