package statAnalysis.singleStatAnalysis;

import java.util.Map;
import java.util.Map.Entry;

import powerEvaluators.PowerEvaluator;
import powerEvaluators.PowerExpectedDamageEvaluator;
import statAnalysis.OneOnOneStatAnalysisProcessor;

/**
 * Reports on the distribution of wins in head-to-head matchups between two
 * {@link PowerEvaluator}s. The wins are distributed over the difference
 * between the damage bonus for a given attack (minus the bonus provided by the
 * relevant ability score modifier) and the ability score modifier itself.
 * 
 * @param <T>
 *          The type of the {@link OneOnOneStatAnalysisProcessor} managing this
 *          single stat analysis object.
 */
public class OneOnOneDamageBonusAbilityModDeltaSingleStatAnalysis<T extends OneOnOneStatAnalysisProcessor> extends
    OneOnOneWinDistributionSingleStatAnalysis<T, Integer>
{
  /**
   * Constructor.
   * 
   * @param statAnalysisProcessor
   *          {@link #statAnalysisProcessor}
   */
  public OneOnOneDamageBonusAbilityModDeltaSingleStatAnalysis(String label, T statAnalysisProcessor)
  {
    super(label, statAnalysisProcessor);
  }

  @Override
  public String report()
  {
    StringBuilder report = new StringBuilder(super.report());

    report
        .append("Distribution of deltas over all the tested scenarios between the ability score mod and the remainder of the damage bonus (a positive number indicates an ability mod greater than a damage bonus):\n\n");
    for (Entry<Integer, DistributionHelper> delta : getWinDistributionMap().entrySet())
    {
      report.append("When the ability score mod is ");
      report.append(Math.abs(delta.getKey()));
      report.append(" points ");
      report.append((delta.getKey() < 0) ? "LESS" : "GREATER");
      report.append(" than the rest of the damage bonus, the percentage of scenarios resulting in a win is: ");
      report.append(convertCountedValueToPercentage(delta.getValue().getWinCount(), delta.getValue().getLossCount()
          + delta.getValue().getWinCount()));
      report.append("%.\n");
    }

    return report.toString();
  }

  @Override
  protected Integer getKey(Map<Class, ? extends PowerExpectedDamageEvaluator> statsMap)
  {
    PowerEvaluator<? extends PowerEvaluator<?, ?>, ?> powerEvaluator = statsMap.get(getStatAnalysisProcessor()
        .getContestant1Class());

    return (powerEvaluator.getAbilityModBonus() - powerEvaluator.getBonusDamage());
  }
}