package statAnalysis.singleStatAnalysis;

import java.util.Map;
import java.util.Map.Entry;

import powerEvaluators.PowerEvaluator;
import powerEvaluators.PowerExpectedDamageEvaluator;
import statAnalysis.OneOnOneStatAnalysisProcessor;

/**
 * Reports on the distribution of wins in head-to-head matchups between two
 * {@link PowerEvaluator}s. The wins are distributed over probability to hit.
 * 
 * @param <T>
 *          The type of the {@link OneOnOneStatAnalysisProcessor} managing this
 *          single stat analysis object.
 */
public class OneOnOneHitChanceDistributionSingleStatAnalysis<T extends OneOnOneStatAnalysisProcessor> extends
    OneOnOneWinDistributionSingleStatAnalysis<T, Integer>
{
  /**
   * Constructor.
   * 
   * @param statAnalysisProcessor
   *          {@link #statAnalysisProcessor}
   */
  public OneOnOneHitChanceDistributionSingleStatAnalysis(String label, T statAnalysisProcessor)
  {
    super(label, statAnalysisProcessor);
  }

  @Override
  public String report()
  {
    StringBuilder report = new StringBuilder(super.report());

    report.append("Distribution of wins over all the tested scenarios :\n\n");
    for (Entry<Integer, DistributionHelper> delta : getWinDistributionMap().entrySet())
    {
      report.append("When the attacker hits on a ");
      report.append(Math.abs(delta.getKey()));
      report.append(", the percentage of scenarios resulting in a win is: ");
      report.append(convertCountedValueToPercentage(delta.getValue().getWinCount(), delta.getValue().getLossCount()
          + delta.getValue().getWinCount()));
      report.append("%.\n");
    }

    return report.toString();
  }

  @Override
  protected Integer getKey(Map<Class, ? extends PowerExpectedDamageEvaluator> statsMap)
  {
    PowerEvaluator<? extends PowerEvaluator<?, ?>, ?> powerEvaluator = statsMap.get(getStatAnalysisProcessor()
        .getContestant1Class());

    return powerEvaluator.getRollRequiredToHit();
  }
}