package statAnalysis.singleStatAnalysis;

import powerEvaluators.PowerEvaluator;
import statAnalysis.OneOnOneStatAnalysisProcessor;

/**
 * A {@link SingleStatAnalysis} for managing head-to-head matchups between
 * {@link PowerEvaluator}s.
 * 
 * @param <T>
 *          The type of the {@link OneOnOneStatAnalysisProcessor} managing this
 *          {@link OneOnOneSingleStatAnalysis}.
 */
public abstract class OneOnOneSingleStatAnalysis<T extends OneOnOneStatAnalysisProcessor> extends SingleStatAnalysis<T>
{
  /**
   * Constructor.
   * 
   * @param statAnalysisProcessor
   *          {@link #statAnalysisProcessor}
   */
  OneOnOneSingleStatAnalysis(String label, T statAnalysisProcessor)
  {
    super(label, statAnalysisProcessor);
  }

  @Override
  public String report()
  {
    StringBuilder report = new StringBuilder();

    report.append('"');
    report.append(getLabel());
    report.append("\" wins ");
    report.append(convertCountedValueToPercentage(getStatAnalysisProcessor().getWinCounter(),
        getStatAnalysisProcessor().getNumberOfStatsAnalysed()));
    report.append("% of the time.\n\n");

    return report.toString();
  }
}
